--Script to install sensors in a default order
--Prevents messing up of sensor references in models after deleting and rediscovering sensors
--start the script WITHOUT powering up te reciever in your model
--Copyright LShems
--GNU free to share



local P = {}
local U = {
  ["Raw (-)"] = 0,
  V           = 1,
  A           = 2,
  mA          = 3,
  kt          = 4,
  ["m/s"]     = 5,
  ["ft/s"]    = 6,
  ["km/h"]    = 7,
  mps         = 8,
  m           = 9,
  ft          = 10,
  ["°C"]      = 11,
  ["°F"]      = 12,
  ["%"]       = 13,
  mAh         = 14,
  W           = 15,
  mW          = 16,
  dB          = 17,
  RPM         = 18,
  G           = 19,
  ["°"]       = 20,
  Rad         = 21,
  mL          = 22,
  ["US fl.Oz."]  = 23,
  hours   = 24,
  minutes = 25,
  seconds = 26,
}  
  
  
--[[
0 Raw unit (no unit)	UNIT_RAW
1	Volts	UNIT_VOLTS
2	Amps	UNIT_AMPS
3	Milliamps	UNIT_MILLIAMPS
4	Knots	UNIT_KTS
5	Meters per Second	UNIT_METERS_PER_SECOND
6	Feet per Second	UNIT_FEET_PER_SECOND
7	Kilometers per Hour	UNIT_KMH
8	Miles per Hour	UNIT_MPH
9	Meters	UNIT_METERS
10	Feet	UNIT_FEET
11	Degrees Celsius	UNIT_CELSIUS
12	Degrees Fahrenheit	UNIT_FAHRENHEIT
13	Percent	UNIT_PERCENT
14	Milliamp Hour	UNIT_MAH
15	Watts	UNIT_WATTS
16	Milliwatts	UNIT_MILLIWATTS
17	dB	UNIT_DB
18	RPM	UNIT_RPMS
19	G	UNIT_G
20	Degrees	UNIT_DEGREE
21	Radians	UNIT_RADIANS
22	Milliliters	UNIT_MILLILITERS
23	Fluid Ounces	UNIT_FLOZ
24	Hours	UNIT_HOURS
25	Minutes	UNIT_MINUTES
26	Seconds	UNIT_SECONDS
27		UNIT_CELLS
28		UNIT_DATETIME
29		UNIT_GPS
30		UNIT_BITFIELD
31		UNIT_TEXT
--]]

local sensorID = 100
local sensorCount = 2
local setTelemetryValue 
local setRSSI = loadfile("/SCRIPTS/TELEMETRY/SENSORS/S101.lua")
local RxBtSource = "RxBt"
local finished = false

P.init = function () 
  setRSSI(U) -- install RSSI sensor first
end
 
P.run= function(event)
  lcd.clear()
  if event == EVT_ENTER_BREAK and not finished then
    sensorID = 2
  end
  if sensorID < 32 then 
    setRSSI(U) --keep setting RSSI to 99 to prevent telemetry lost
    setTelemetryValue = setTelemetryValue 
                or loadfile("/SCRIPTS/TELEMETRY/SENSORS/S" .. 100+sensorID .. ".lua") 
-- or loadfile("/SCRIPTS/TELEMETRY/SENSORS/Sdummy.lua") --uncomment if you want fixed positions
    if setTelemetryValue then
      if RxBtSource == "A1" then 
        if sensorID == 2 then
          setTelemetryValue = loadfile("/SCRIPTS/TELEMETRY/SENSORS/S103.lua") 
        elseif sensorID == 3 then
          setTelemetryValue = loadfile("/SCRIPTS/TELEMETRY/SENSORS/S102.lua") 
        end
      end
      if setTelemetryValue(U,sensorID) then
        sensorID = sensorID + 1
        sensorCount = sensorCount + 1
        setTelemetryValue = nil
      end
    else
      sensorID = sensorID + 1
    end 
    lcd.drawText(10,10,"Stopped at sensor " .. sensorCount)
    lcd.drawText(10,20,"Delete ALL sensors first")
    lcd.drawText(10,30,"Start the autodiscovery")
    lcd.drawText(10,40,"Press Enter when ready to restart")
  elseif sensorID < 100 then
    lcd.drawText(10,10,"installed " .. sensorCount .. " sensors")    
    lcd.drawText(10,20,"set scale to 13.2 for RxBt, A1 and A2 !!")    
    lcd.drawText(10,30,"check Auto Offset for Alt if desired")
    finished = true
  else
    RxBtSource = ((event == EVT_PLUS_BREAK) or (event == EVT_MINUS_BREAK)) and ((RxBtSource == "RxBt") and "A1" or "RxBt") or RxBtSource
    lcd.drawText(10,10,"Top Bar Volt. Source (+/- to edit): " .. RxBtSource)
    lcd.drawText(10,20,"Delete ALL sensors first")
    lcd.drawText(10,30,"Start the autodiscovery")
    lcd.drawText(10,40,"Press Enter when ready to start")
    
  end
  return 0
end

return P